package io.skore.smooch_plugin

import android.content.BroadcastReceiver
import android.content.Context
import android.content.Intent
import android.content.IntentFilter
import android.os.Bundle
import android.util.Log
import androidx.localbroadcastmanager.content.LocalBroadcastManager
import io.flutter.plugin.common.MethodChannel
import io.smooch.core.Smooch
import io.smooch.ui.ConversationActivity
import kotlinx.android.synthetic.main.smooch_activity_conversation.*

const val ACTION_MINIMIZE_SMOOCH = "ACTION_MINIMIZE_SMOOCH"
const val ACTION_UNKNOWN = "ACTION_UNKNOWN"

class SmoochActivity : ConversationActivity() {
    private val TAG = SmoochActivity::class.java.simpleName

    private val broadcastReceiver = object : BroadcastReceiver() {
        override fun onReceive(context: Context?, intent: Intent?) {
            Log.d(TAG, "Broadcast received: ${intent?.action ?: ACTION_UNKNOWN}")

            if (intent?.action == ACTION_MINIMIZE_SMOOCH) {
                onBackPressed()
            }
        }
    }

    companion object {
        @JvmStatic
        fun start(channel: MethodChannel) {

        }
    }

    override fun attachBaseContext(baseContext: Context?) {
        super.attachBaseContext(if (baseContext != null) LangPreference.updateResources(baseContext, LangPreference.getLang(baseContext)) else null)
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        logSmoochStatus()

        supportActionBar?.setDisplayHomeAsUpEnabled(false)

        back.setOnClickListener {
            onBackPressed()
        }

        LocalBroadcastManager.getInstance(this).registerReceiver(broadcastReceiver, IntentFilter(ACTION_MINIMIZE_SMOOCH))
    }

    private fun logSmoochStatus() {
        val connectionStatus = Smooch.getSmoochConnectionStatus()
        val initStatus = Smooch.getInitializationStatus()
        val loginStatus = Smooch.getLastLoginResult()
        Log.d(TAG, "Smooch status\nConnection: ${connectionStatus?.name ?: "unknown"}\nInit: ${initStatus?.name ?: "unknown"}\nLogin: ${loginStatus?.name ?: "unknown"}")
    }
}